### Name: epi.ccc
### Title: Concordance correlation coefficient
### Aliases: epi.ccc
### Keywords: univar

### ** Examples

## Concordance correlation plot:
set.seed(seed = 1234)
method1 <- rnorm(n = 100, mean = 0, sd = 1)
method2 <- method1 + runif(n = 100, min = 0, max = 1)

tmp.ccc <- epi.ccc(method1, method2, ci = "z-transform",
   conf.level = 0.95)

lab <- paste("CCC: ", round(tmp.ccc$rho.c[,1], digits = 2), " (95% CI ", 
   round(tmp.ccc$rho.c[,2], digits = 2), " - ",
   round(tmp.ccc$rho.c[,3], digits = 2), ")", sep = "")
z <- lm(method2 ~ method1)

par(pty = "s")
plot(method1, method2, xlim = c(0, 5), ylim = c(0,5), xlab = "Method 1", 
   ylab = "Method 2", pch = 16)
abline(a = 0, b = 1, lty = 2)
abline(z, lty = 1)
legend(x = -0.2, y = 4.75, legend = c("Line of perfect concordance", 
   "Reduced major axis"), lty = c(2,1), lwd = c(1,1), bty = "n")
text(x = 1.55, y = 3.8, labels = lab)

## Bland and Altman plot:
x <- c(494,395,516,434,476,557,413,442,650,433,417,656,267,
   478,178,423,427)
y <- c(490,397,512,401,470,611,415,431,638,429,420,633,275,
   492,165,372,421)

tmp.ccc <- epi.ccc(x, y, ci = "z-transform", conf.level = 0.95)
mean <- mean(tmp.ccc$blalt$delta)
sd <- sqrt(var(tmp.ccc$blalt$delta))

xlim <- c(min(tmp.ccc$blalt$mean), max(tmp.ccc$blalt$mean))
ylim <- c(-100, 100)

plot(tmp.ccc$blalt$mean, tmp.ccc$blalt$delta, pch = 16, xlab = "Mean", 
   ylab = "Difference", xlim = xlim, ylim = ylim) 
abline(h = mean, lty = 1)
abline(h = mean - (2 * sd), lty = 2)
abline(h = mean + (2 * sd), lty = 2)
legend(x = 200, y = 100, legend = c("Difference"), pch = 16, bty = "n")
legend(x = 180, y = 90, legend = c("Mean difference", 
   "Mean difference +/ 2SD"), lty = c(1,2), bty = "n")



